@@ -1,20 +1,21 @@
-from typing import Callable, Optional, Union, overload
+from typing import Any, Callable, Optional, Union, overload
 
 from .mocks import MockTransport
-from .models import (
-    CallList,
+from .models import CallList, Route
+from .patterns import Pattern
+from .types import (
     ContentDataTypes,
     DefaultType,
     HeaderTypes,
     JSONTypes,
     QueryParamTypes,
-    RequestPattern,
     URLPatternTypes,
 )
 
 mock = MockTransport(assert_all_called=False)
 
-aliases = mock.aliases
+aliases = mock.routes
+routes = mock.routes
 stats = mock.calls
 calls: CallList = mock.calls
 
@@ -40,22 +41,27 @@ def reset() -> None:
 
 
 @overload
-def pop(alias: str) -> RequestPattern:
+def pop(name: str) -> Route:
     ...  # pragma: nocover
 
 
 @overload
-def pop(alias: str, default: DefaultType) -> Union[RequestPattern, DefaultType]:
+def pop(name: str, default: DefaultType) -> Union[Route, DefaultType]:
     ...  # pragma: nocover
 
 
-def pop(alias, default=...):
+def pop(name, default=...):
     global mock
-    return mock.pop(alias=alias, default=default)
+    return mock.pop(name, default=default)
+
+
+def route(*patterns: Pattern, name: Optional[str] = None, **lookups: Any) -> Route:
+    global mock
+    return mock.route(*patterns, name=name, **lookups)
 
 
 def add(
-    method: Union[str, Callable],
+    method: Union[str, Callable, Route],
     url: Optional[URLPatternTypes] = None,
     *,
     params: Optional[QueryParamTypes] = None,
@@ -68,7 +74,9 @@ def add(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.add(
         method,
@@ -83,6 +91,8 @@ def add(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
 
 
@@ -99,7 +109,9 @@ def get(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.get(
         url=url,
@@ -113,6 +125,8 @@ def get(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
 
 
@@ -129,7 +143,9 @@ def post(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.post(
         url=url,
@@ -143,6 +159,8 @@ def post(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
 
 
@@ -159,7 +177,9 @@ def put(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.put(
         url=url,
@@ -173,6 +193,8 @@ def put(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
 
 
@@ -189,7 +211,9 @@ def patch(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.patch(
         url=url,
@@ -203,6 +227,8 @@ def patch(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
 
 
@@ -219,7 +245,9 @@ def delete(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.delete(
         url=url,
@@ -233,6 +261,8 @@ def delete(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
 
 
@@ -249,7 +279,9 @@ def head(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.head(
         url=url,
@@ -263,6 +295,8 @@ def head(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
 
 
@@ -279,7 +313,9 @@ def options(
     json: Optional[JSONTypes] = None,
     pass_through: bool = False,
     alias: Optional[str] = None,
-) -> RequestPattern:
+    name: Optional[str] = None,
+    **lookups: Any,
+) -> Route:
     global mock
     return mock.options(
         url=url,
@@ -293,4 +329,6 @@ def options(
         json=json,
         pass_through=pass_through,
         alias=alias,
+        name=name,
+        **lookups,
     )
